@@ -536,6 +536,8 @@ class TranslateJson(object):
             self.max_len = len(self.path_addr_dict[self.js_dpath[-1]][2:])
             for i in self.js_dpath:
                 self.create_md3(i, lm)
+            self.relist(self.all_reg_list)
+            self.create_all_reg_data(lm)
             self.data = "# 寄存器列表\n" + self.all_reg_data + "\n"\
                     + "# 寄存器详细说明\n" + self.data.replace("#", "##")
             with open(md_file, 'w') as fd:
